@@ -3,20 +3,12 @@
 """class for detecting junction reads
 
 """
+import time
+
 import pysam as ps
 
-from .utils import get_yaml
 from .utils import timethis
 
-# change keys to be consist with chromosome's values
-CHROMS = get_yaml()["chr2hg38"]
-
-POSITIVE_SITE, NIGATIVE_SITE = [("GT", "AG"), ("AT", "AC"), ("GC", "AG")], [
-    ("CT", "AC"),
-    ("GT", "AT"),
-    ("CT", "GC"),
-]
-
 
 class Read:
     """build a read class for storing information of every junction read
@@ -64,8 +56,8 @@ class Read:
 
     def __repr__(self):
         return (
-            f"Read({self.chrom!r}, {self.start!r}, {self.end!r}, {self.idn!r}, "
-            f"{self.score!r}, {self.strand!r}, {self.anchor!r}, {self.acceptor!r})"
+            fr"Read({self.chrom}, {self.start}, {self.end}, {self.idn}, "
+            fr"{self.score}, {self.strand}, {self.anchor}, {self.acceptor})"
         )
 
     def __str__(self):
@@ -88,8 +80,17 @@ class Read:
 class JunctionMap:
     """build a class to store information of all junction reads"""
 
-    def __init__(self):
+    def __init__(self, chrom):
+        self.chrom = chrom
         self.junctionList = {}
+        self.result = None
+
+    def is_empty(self):
+
+        if len(self.junctionList):
+            return False
+        else:
+            return True
 
     def add_read(self, read):
         """add read to  junctionlist
@@ -123,6 +124,9 @@ class JunctionMap:
         """iterate every read in junctionlist"""
         return iter(self.junctionList.values())
 
+    def __repr__(self):
+        return f"ce_detector.detector.JunctionMap(chrom = {self.chrom})"
+
     def write2file(self, output, header=None):
         """write all reads in junctionlist to file
 
@@ -155,13 +159,18 @@ class JunctionDetector:
     :type quality: int
     """
 
-    def __init__(self, bam_file, reference, quality=0, output=None):
+    SPLICE_SITE = dict(
+        zip([("GT", "AG"), ("AT", "AC"), ("GC", "AG")], "+++")
+    )  # positive site
+    SPLICE_SITE.update(
+        dict(zip([("CT", "AC"), ("GT", "AT"), ("CT", "GC")], "---"))
+    )  # negative site
 
-        self.bam_file, self.output = bam_file, output
+    def __init__(self, bam_file, reference, quality, output=None):
 
-        self.reference = reference
+        self.bam, self.reference = ps.AlignmentFile(bam_file), ps.FastaFile(reference)
 
-        self.quality = quality
+        self.output, self.quality = output, quality
 
     @staticmethod
     def check_strand(anchor, acceptor):
@@ -174,19 +183,12 @@ class JunctionDetector:
         :return: type of strand (-|+)
         :rtype: str
         """
-        strand = "N"
 
-        if (anchor, acceptor) in POSITIVE_SITE:
-
-            strand = "+"
-
-        elif (anchor, acceptor) in NIGATIVE_SITE:
-
-            strand = "-"
+        strand = JunctionDetector.SPLICE_SITE.get((anchor, acceptor), "N")
 
         return strand
 
-    def worker(self, bam_file, reference, chrom, quality, idn, junctionmap):
+    def worker(self, bam_file, reference, chrom, ann_chrom, quality, idn, junctionmap):
         """find junction reads and annotate slice site
 
         :param bam_file: handle of bam_file
@@ -216,7 +218,7 @@ class JunctionDetector:
         # annotate slice sites
         for ((start, end), score) in junction_regions.items():
             junction_bases = reference.fetch(
-                reference=CHROMS[chrom],
+                reference=ann_chrom,
                 start=start,
                 end=end,  # change chrom
             )
@@ -225,12 +227,13 @@ class JunctionDetector:
             strand = self.check_strand(anchor, acceptor)
             read = Read(chrom, start, end, idn + 1, score, strand, anchor, acceptor)
             junctionmap.add_read(read)
-            #             line = f'{chrom}\t{start}\t{end}\t{idn+1}\t{score}\t{strand}\t{anchor}-{acceptor}'
 
             idn += 1
 
-    @timethis(name="Junction detector", message="FINISHED")
-    def run(self, logger, verbose=False):
+        return junctionmap
+
+    @timethis(name="Junction detector", message=" ")
+    def run(self, chrom, ann_chrom, logger, verbose=False):
         """detect junction reads and annotate slice site, write results to file
 
         :return: instance from junctionmap
@@ -239,19 +242,21 @@ class JunctionDetector:
 
         idn = 0
 
-        reference = ps.FastaFile(self.reference)
-
-        bam = ps.AlignmentFile(self.bam_file)
-
-        junctionmap = JunctionMap()
+        junctionmap = JunctionMap(chrom)
 
         # write junction reads information
-        for chrom in CHROMS.keys():  # change CHROMS
-            self.worker(bam, reference, chrom, self.quality, idn, junctionmap)
-            if verbose:
-                logger.info(f"Chrom {chrom} Finished")
+        if verbose:
+            logger.info(f"Chrom {chrom} Beginning")
+            start = time.time()
 
-        if self.output:
-            junctionmap.write2file(self.output)  # write to file
+        junctionmap = self.worker(
+            self.bam, self.reference, chrom, ann_chrom, self.quality, idn, junctionmap
+        )
+
+        if verbose:
+            logger.info(f"Chrom {chrom} Finished {time.time() - start:.2f}s")
+        #
+        # if self.output:
+        #     junctionmap.write2file(self.output)  # write to file
 
         return junctionmap
